% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict.splitSelect.R
\name{predict.splitSelect}
\alias{predict.splitSelect}
\title{Predictions for splitSelect object}
\usage{
\method{predict}{splitSelect}(object, newx, ...)
}
\arguments{
\item{object}{An object of class splitSelect.}

\item{newx}{A matrix with the new data.}

\item{...}{Additional arguments for compatibility.}
}
\value{
A matrix with the predictions of the \code{splitSelect} object.
}
\description{
\code{predict.splitSelect} returns the prediction for splitSelect for new data.
}
\examples{
# Setting the parameters
p <- 4
n <- 30
n.test <- 5000
beta <- rep(5,4)
rho <- 0.1
r <- 0.9
SNR <- 3
# Creating the target matrix with "kernel" set to rho
target_cor <- function(r, p){
  Gamma <- diag(p)
  for(i in 1:(p-1)){
    for(j in (i+1):p){
      Gamma[i,j] <- Gamma[j,i] <- r^(abs(i-j))
    }
  }
  return(Gamma)
}
# AR Correlation Structure
Sigma.r <- target_cor(r, p)
Sigma.rho <- target_cor(rho, p)
sigma.epsilon <- as.numeric(sqrt((t(beta) \%*\% Sigma.rho \%*\% beta)/SNR))
# Simulate some data
x.train <- mvnfast::rmvn(30, mu=rep(0,p), sigma=Sigma.r)
y.train <- 1 + x.train \%*\% beta + rnorm(n=n, mean=0, sd=sigma.epsilon)
x.test <- mvnfast::rmvn(n.test, mu=rep(0,p), sigma=Sigma.rho)
y.test <- 1 + x.test \%*\% beta + rnorm(n.test, sd=sigma.epsilon)

# Generating the coefficients for a fixed split
\donttest{
split.out <- splitSelect(x.train, y.train, G=2, use.all=TRUE,
                         fix.partition=list(matrix(c(2,2), ncol=2, byrow=TRUE)), fix.split=NULL,
                         intercept=TRUE, group.model="glmnet", alphas=0)
predict(split.out, newx=x.test)
}

}
\seealso{
\code{\link{splitSelect}}
}
\author{
Anthony-Alexander Christidis, \email{anthony.christidis@stat.ubc.ca}
}
